[Libreoffice-commits] .: binfilter/bf_sc

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Sat Aug 18 13:15:06 PDT 2012


 binfilter/bf_sc/source/core/data/sc_global2.cxx  |    3 ++-
 binfilter/bf_sc/source/core/tool/sc_chgviset.cxx |    3 ++-
 binfilter/bf_sc/source/core/tool/sc_interpr1.cxx |    3 ++-
 3 files changed, 6 insertions(+), 3 deletions(-)

New commits:
commit 45e5d267628612064e201cb09dcce09581599609
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date:   Sat Aug 18 15:11:33 2012 -0500

    fix fallout of c1b73536343ae0a7b6dd940b1c8a01784c4d7a30

diff --git a/binfilter/bf_sc/source/core/tool/sc_chgviset.cxx b/binfilter/bf_sc/source/core/tool/sc_chgviset.cxx
index 183831c..ac9dee8 100644
--- a/binfilter/bf_sc/source/core/tool/sc_chgviset.cxx
+++ b/binfilter/bf_sc/source/core/tool/sc_chgviset.cxx
@@ -68,7 +68,8 @@ ScChangeViewSettings& ScChangeViewSettings::operator=( const ScChangeViewSetting
 /*N*/
 /*N*/   if(rString.Len()>0)
 /*N*/   {
-/*N*/       utl::SearchParam aSearchParam( rString,
+            ::rtl::OUString search(rString);
+/*N*/       utl::SearchParam aSearchParam( search,
 /*N*/           utl::SearchParam::SRCH_REGEXP,FALSE,FALSE,FALSE );
 /*N*/
 /*N*/       pCommentSearcher = new utl::TextSearch( aSearchParam, *ScGlobal::pCharClass );
diff --git a/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx b/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx
index cf183ac..c4f834c 100644
--- a/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx
+++ b/binfilter/bf_sc/source/core/tool/sc_interpr1.cxx
@@ -5151,6 +5151,7 @@ void ScInterpreter::ScSearch()
             fAnz = 1.0;
         String sStr = GetString();
         String SearchStr = GetString();
+        ::rtl::OUString search_string(SearchStr);
         xub_StrLen nPos = (xub_StrLen) fAnz - 1;
         xub_StrLen nEndPos = sStr.Len();
         if( nPos >= nEndPos )
@@ -5160,7 +5161,7 @@ void ScInterpreter::ScSearch()
             ::utl::SearchParam::SearchType eSearchType =
                 (MayBeRegExp( SearchStr, pDok ) ?
                 ::utl::SearchParam::SRCH_REGEXP : ::utl::SearchParam::SRCH_NORMAL);
-            ::utl::SearchParam sPar(SearchStr, eSearchType, FALSE, FALSE, FALSE);
+            ::utl::SearchParam sPar(search_string, eSearchType, FALSE, FALSE, FALSE);
             ::utl::TextSearch sT( sPar, *ScGlobal::pCharClass );
             int nBool = sT.SearchFrwrd(sStr, &nPos, &nEndPos);
             if (!nBool)


More information about the Libreoffice-commits mailing list
diff --git a/binfilter/bf_sc/source/core/data/sc_global2.cxx b/binfilter/bf_sc/source/core/data/sc_global2.cxx
index 7baacf1..5c971fc 100644
--- a/binfilter/bf_sc/source/core/data/sc_global2.cxx
+++ b/binfilter/bf_sc/source/core/data/sc_global2.cxx
@@ -218,7 +218,8 @@ namespace binfilter {
 /*N*/ {
 /*N*/   if ( !pSearchParam )
 /*N*/   {
-/*N*/       pSearchParam = new ::utl::SearchParam( *pStr, utl::SearchParam::SRCH_REGEXP,
+            ::rtl::OUString search_string(*pStr);
+/*N*/       pSearchParam = new ::utl::SearchParam( search_string, utl::SearchParam::SRCH_REGEXP,
 /*N*/           bCaseSens, FALSE, FALSE );
 /*N*/       pSearchText = new ::utl::TextSearch( *pSearchParam, *ScGlobal::pCharClass );
 /*N*/   }